/***************************************************************************//**
* \file CapSense_1_Adc.h
* \version 3.0
*
* \brief
*   This file provides the sources of APIs specific to the ADC implementation.
*
* \see CapSense_1 v3.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2017), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSense_1_ADC_H)
#define CY_SENSE_CapSense_1_ADC_H

#include "syslib/cy_syslib.h"
#include "CapSense_1_Configuration.h"
#if (CapSense_1_ENABLE == CapSense_1_ADC_STANDALONE_EN)
    #include "syspm/cy_syspm.h"
#endif  /* (CapSense_1_ENABLE == CapSense_1_ADC_STANDALONE_EN) */
#include "CapSense_1_Structure.h"

#if (CapSense_1_ADC_EN)

/*******************************************************************************
* Function Prototypes
*******************************************************************************/

/**
* \cond SECTION_STANDALONE_ADC
* \addtogroup group_adc_public
* \{
*/
#if (CapSense_1_ENABLE == CapSense_1_ADC_STANDALONE_EN)
    void CapSense_1_Start(void);
    void CapSense_1_Sleep(void);
    void CapSense_1_Wakeup(void);

    cy_en_syspm_status_t CapSense_1_DeepSleepCallback(
                     cy_stc_syspm_callback_params_t * callbackParams,
                     cy_en_syspm_callback_mode_t mode);

#endif  /* (CapSense_1_ENABLE == CapSense_1_ADC_STANDALONE_EN) */
/** \}
* \endcond */

/**
* \cond SECTION_ADC_PUBLIC
* \addtogroup group_adc_public
* \{
*/

cy_status CapSense_1_AdcStartConvert(uint8 chId);
uint8 CapSense_1_AdcIsBusy(void);
uint16 CapSense_1_AdcReadResult_mVolts(uint8 chId);
uint16 CapSense_1_AdcGetResult_mVolts(uint8 chId);
cy_status CapSense_1_AdcCalibrate(void);

void CapSense_1_Stop(void);
void CapSense_1_Resume(void);

/** \}
* \endcond */

void CapSense_1_AdcIntrHandler(void);

/**
* \cond SECTION_ADC_INTERNAL
* \addtogroup group_adc_internal
* \{
*/

void CapSense_1_AdcInitialize(void);
void CapSense_1_SetAdcChannel(uint8 chId, uint32 state);
void CapSense_1_ConfigAdcResources(void);
void CapSense_1_StartAdcFSM(uint32 measureMode);
cy_status CapSense_1_AdcCaptureResources(void);
cy_status CapSense_1_AdcReleaseResources(void);
void CapSense_1_ClearAdcChannels(void);
void CapSense_1_SetNonDedicatedAdcChannel(uint8 chId, uint32 state);

/** \}
* \endcond */

/**************************************
* Global software/external variables
**************************************/

extern uint16 CapSense_1_adcVrefMv;

/**************************************
*           API Constants
**************************************/

/* Error value if given bad channel ID. */
#define CapSense_1_AdcVALUE_BAD_CHAN_ID            (0x0000FFFFuL)
#define CapSense_1_AdcVALUE_BAD_RESULT             (0x0000FFFFuL)

/* Statuses defined for use with IsBusy */
#define CapSense_1_AdcSTATUS_LASTCHAN_MASK         (0x0000000FuL)
#define CapSense_1_AdcSTATUS_FSM_MASK              (0x000000F0uL)
#define CapSense_1_AdcSTATUS_IDLE                  (0x00u)
#define CapSense_1_AdcSTATUS_CALIBPH1              (0x10u)
#define CapSense_1_AdcSTATUS_CALIBPH2              (0x20u)
#define CapSense_1_AdcSTATUS_CALIBPH3              (0x30u)
#define CapSense_1_AdcSTATUS_CONVERTING            (0x40u)
#define CapSense_1_AdcSTATUS_OVERFLOW              (0x80u)

/* Potential channel states */
#define CapSense_1_AdcCHAN_CONNECT                 (1uL)
#define CapSense_1_AdcCHAN_DISCONNECT              (0uL)

/* Active channel when ADC is not configured */
#define CapSense_1_AdcNO_CHANNEL                   (0xFFu)

/* Input/Output constants */
#define CapSense_1_AdcHSIOM_PRTSEL_GPIO            (HSIOM_SEL_GPIO)
#define CapSense_1_AdcHSIOM_PRTSEL_AMUXBUSB        (HSIOM_SEL_AMUXB)

#define CapSense_1_AdcGPIO_PC_DISCONNECT           (CY_GPIO_DM_ANALOG)
#define CapSense_1_AdcGPIO_PC_INPUT                (CY_GPIO_DM_HIGHZ)

/* Default filter delay */
#define CapSense_1_AdcFILTER_DELAY_DEFAULT         (2uL)

/* Adc Config */
#define CapSense_1_AdcCONFIG_DEFAULT               (CSD_CONFIG_ENABLE_Msk | \
                                                                            CSD_CONFIG_SAMPLE_SYNC_Msk | \
                                                                            CSD_CONFIG_SENSE_EN_Msk | \
                                                                            CSD_CONFIG_DSI_COUNT_SEL_Msk | \
                                                                            (CapSense_1_AdcFILTER_DELAY_DEFAULT << CSD_CONFIG_FILTER_DELAY_Pos))

/* Measurement modes */
#define CapSense_1_AdcMEASMODE_OFF                 (0x0uL << CSD_ADC_CTL_ADC_MODE_Pos)
#define CapSense_1_AdcMEASMODE_VREF                (0x1uL << CSD_ADC_CTL_ADC_MODE_Pos)
#define CapSense_1_AdcMEASMODE_VREFBY2             (0x2uL << CSD_ADC_CTL_ADC_MODE_Pos)
#define CapSense_1_AdcMEASMODE_VIN                 (0x3uL << CSD_ADC_CTL_ADC_MODE_Pos)

/* Clock defines */
#define CapSense_1_AdcSENSE_DIV_DEFAULT            (0x4uL)
#define CapSense_1_AdcTOTAL_CLOCK_DIV              (CapSense_1_ADC_MODCLK_DIV_DEFAULT * \
                                                                         CapSense_1_AdcSENSE_DIV_DEFAULT)

/* The MAX possible value of the AZ time in CSD_SENSE cycles. The value is limited by the width of the SEQ_TIME register */
#define CapSense_1_ADC_SEQ_TIME_MAX                               (0x100u)

#define CapSense_1_ADC_SEQ_TIME_CYCLES                            (((CYDEV_CLK_PERICLK__HZ * CapSense_1_ADC_AZ_TIME) / \
                                                                         CapSense_1_AdcTOTAL_CLOCK_DIV) / 1000000uL)

#if (CapSense_1_ADC_SEQ_TIME_MAX < CapSense_1_ADC_SEQ_TIME_CYCLES)
    #define CapSense_1_AdcSEQ_TIME_BASE            (CapSense_1_ADC_SEQ_TIME_MAX)
#else
    #define CapSense_1_AdcSEQ_TIME_BASE            (CapSense_1_ADC_SEQ_TIME_CYCLES)
#endif

#if (0 == CapSense_1_AdcSEQ_TIME_BASE)
    #define CapSense_1_AdcSEQ_TIME_DEFAUL          (1u)
#else
    #define CapSense_1_AdcSEQ_TIME_DEFAUL          (CapSense_1_AdcSEQ_TIME_BASE)
#endif

/* Acquisition time definitions: ADC_CTL */
#define CapSense_1_AdcACQUISITION_TIME_US          (10uL)
#define CapSense_1_AdcACQUISITION_BASE             ((CapSense_1_AdcACQUISITION_TIME_US * \
                                                                        (CYDEV_CLK_PERICLK__MHZ)) / \
                                                                         CapSense_1_AdcTOTAL_CLOCK_DIV)

/* SEQ_START field definitions */
#define CapSense_1_AdcFSMSETTING_ABORT             (0x1uL << CSD_SEQ_START_ABORT_Pos)
#define CapSense_1_AdcFSMSETTING_DSI_START_EN      (0x1uL << CSD_SEQ_START_DSI_START_EN_Pos)
#define CapSense_1_AdcFSMSETTING_AZ0SKIP           (0x1uL << CSD_SEQ_START_AZ0_SKIP_Pos)
#define CapSense_1_AdcFSMSETTING_AZ1SKIP           (0x1uL << CSD_SEQ_START_AZ1_SKIP_Pos)


#define CapSense_1_AdcFSMSETTING_NOAZSKIP          (0uL)
#define CapSense_1_AdcFSMSETTING_AZSKIP_DEFAULT    (CapSense_1_AdcFSMSETTING_AZ0SKIP \
                                                                            | ((0u != CapSense_1_ADC_AZ_EN) \
                                                                            ? 0u \
                                                                            : CapSense_1_AdcFSMSETTING_AZ1SKIP))
#define CapSense_1_AdcFSMSETTING_DSIIGNORE         (0x00000000uL)
#define CapSense_1_AdcFSMSETTING_NOABORT           (0x00000000uL)
#define CapSense_1_AdcFSMSETTING_SEQMODE           (0x00000000uL)
#define CapSense_1_AdcFSMSETTING_START             (0x00000001uL)

/* IDACB definitions
*  The idac configuration for ADC use is mostly static, with only the VAL field varying.
*   Dynamic Polarity = 1 << 7
*   Polarity (normal) = 0 << 8
*   Balance, Leg1, Leg2 modes = don't care.
*   DSI Control Enable (no mix) = 0 << 21
*   Range (low) = 0 << 22
*   Leg1, Leg2 enable = 0
*   Leg3 enable = 1 << 26
*/
#define CapSense_1_AdcIDACB_CONFIG                 (0x04000080uL)
#define CapSense_1_AdcCLK16_MASK                   (0xFFFFuL)
#define CapSense_1_AdcCLK16VAL_SHIFT               (8uL)

/* Switch definitions */
#define CapSense_1_AdcSW_HSP_DEFAULT               (0x10000000uL)
#define CapSense_1_AdcSW_HSN_DEFAULT               (0x00100000uL)
#define CapSense_1_AdcSW_HSP_GETINPOL              (0x00010000uL)
#define CapSense_1_AdcSW_HSN_GETINPOL              (0x01000000uL)
#define CapSense_1_AdcSW_SHIELD_DEFAULT            (0x00000000uL)
#define CapSense_1_AdcSW_SHIELD_VDDA2CSDBUSB       (0x00000100uL)
#define CapSense_1_AdcSW_BYP_DEFAULT               (0x00110000uL)
#define CapSense_1_AdcSW_CMPP_DEFAULT              (0x00000000uL)
#define CapSense_1_AdcSW_CMPN_DEFAULT              (0x00000000uL)
#define CapSense_1_AdcSW_REFGEN_DEFAULT            (0x10000000uL)

#define CapSense_1_AdcSW_FWMOD_DEFAULT             (0x01100000uL)
#define CapSense_1_AdcSW_FWTANK_DEFAULT            (0x01100000uL)

/* The reference voltage macros */
#define CapSense_1_AdcVREF_CALIB_BASE_0_8          (800uL)
#define CapSense_1_AdcVREF_CALIB_BASE_1_2          (1164uL)
#define CapSense_1_AdcVREF_CALIB_BASE_1_6          (1600uL)
#define CapSense_1_AdcVREF_CALIB_BASE_2_1          (2133uL)
#define CapSense_1_AdcVREF_CALIB_BASE_2_6          (2600uL)

#if (CapSense_1_ADC_VREF_MV < CapSense_1_AdcVREF_CALIB_BASE_1_2)
    #define CapSense_1_AdcVREF_CALIB_USED          (CapSense_1_AdcVREF_CALIB_BASE_0_8)
    #define CapSense_1_AdcVREF_TRIM_REG            (SFLASH->CSDV2_CSD0_ADC_VREF1)
    #define CapSense_1_AdcVREF_TRIM_POS            (SFLASH_CSDV2_CSD0_ADC_VREF1_VREF_HI_LEVELS_0P8_Pos)
    #define CapSense_1_AdcVREF_TRIM_MSK            (SFLASH_CSDV2_CSD0_ADC_VREF1_VREF_HI_LEVELS_0P8_Msk)
#elif (CapSense_1_ADC_VREF_MV < CapSense_1_AdcVREF_CALIB_BASE_1_6)
    #define CapSense_1_AdcVREF_CALIB_USED          (CapSense_1_AdcVREF_CALIB_BASE_1_2)
    #define CapSense_1_AdcVREF_TRIM_REG            (SFLASH->CSDV2_CSD0_ADC_VREF0)
    #define CapSense_1_AdcVREF_TRIM_POS            (SFLASH_CSDV2_CSD0_ADC_VREF0_VREF_HI_LEVELS_1P2_Pos)
    #define CapSense_1_AdcVREF_TRIM_MSK            (SFLASH_CSDV2_CSD0_ADC_VREF0_VREF_HI_LEVELS_1P2_Msk)
#elif (CapSense_1_ADC_VREF_MV < CapSense_1_AdcVREF_CALIB_BASE_2_1)
    #define CapSense_1_AdcVREF_CALIB_USED          (CapSense_1_AdcVREF_CALIB_BASE_1_6)
    #define CapSense_1_AdcVREF_TRIM_REG            (SFLASH->CSDV2_CSD0_ADC_VREF0)
    #define CapSense_1_AdcVREF_TRIM_POS            (SFLASH_CSDV2_CSD0_ADC_VREF0_VREF_HI_LEVELS_1P6_Pos)
    #define CapSense_1_AdcVREF_TRIM_MSK            (SFLASH_CSDV2_CSD0_ADC_VREF0_VREF_HI_LEVELS_1P6_Msk)
#elif (CapSense_1_ADC_VREF_MV < CapSense_1_AdcVREF_CALIB_BASE_2_6)
    #define CapSense_1_AdcVREF_CALIB_USED          (CapSense_1_AdcVREF_CALIB_BASE_2_1)
    #define CapSense_1_AdcVREF_TRIM_REG            (SFLASH->CSDV2_CSD0_ADC_VREF1)
    #define CapSense_1_AdcVREF_TRIM_POS            (SFLASH_CSDV2_CSD0_ADC_VREF1_VREF_HI_LEVELS_2P1_Pos)
    #define CapSense_1_AdcVREF_TRIM_MSK            (SFLASH_CSDV2_CSD0_ADC_VREF1_VREF_HI_LEVELS_2P1_Msk)
#else
    #define CapSense_1_AdcVREF_CALIB_USED          (CapSense_1_AdcVREF_CALIB_BASE_2_6)
    #define CapSense_1_AdcVREF_TRIM_REG            (SFLASH->CSDV2_CSD0_ADC_VREF2)
    #define CapSense_1_AdcVREF_TRIM_POS            (SFLASH_CSDV2_CSD0_ADC_VREF2_VREF_HI_LEVELS_2P6_Pos)
    #define CapSense_1_AdcVREF_TRIM_MSK            (SFLASH_CSDV2_CSD0_ADC_VREF2_VREF_HI_LEVELS_2P6_Msk)
#endif

#define CapSense_1_AdcVREF_TRIM_MAX_DEVIATION      (20uL)

/* RefGen settings */
#define CapSense_1_AdcREFGEN_GAIN_SHIFT            (CSD_REFGEN_GAIN_Pos)

/* At low voltage, REFGEN is enabled and bypassed. */
#define CapSense_1_AdcREFGEN_LV                    (0x00000011uL)
#define CapSense_1_AdcSW_AMUBUF_LV                 (0x01000100uL)
#define CapSense_1_AdcAMBUF_LV                     (0x00000002uL)
/* At normal voltage, REFGEN uses customizer-defined gain */
#define CapSense_1_AdcREFGEN_NORM                  (0x00000041UL | (CapSense_1_ADC_GAIN << \
                                                                            CapSense_1_AdcREFGEN_GAIN_SHIFT))
#define CapSense_1_AdcSW_AMUBUF_NORM               (0x00000000uL)

/* HSCOMP definitions */
#define CapSense_1_AdcHSCMP_AZ_DEFAULT             (CSD_HSCMP_HSCMP_EN_Msk | (CapSense_1_ADC_AZ_EN << CSD_HSCMP_AZ_EN_Pos))
#define CapSense_1_AdcSTATUS_HSCMP_OUT_MASK        (CSD_HSCMP_HSCMP_INVERT_Msk)

/* ADC_RES definitions */
#define CapSense_1_AdcRES_MAX                      ((1uL << CapSense_1_ADC_RESOLUTION) - 1uL)
#define CapSense_1_AdcADC_RES_OVERFLOW_MASK        (CSD_ADC_RES_ADC_OVERFLOW_Msk)
#define CapSense_1_AdcADC_RES_ABORT_MASK           (CSD_ADC_RES_ADC_ABORT_Msk)
#define CapSense_1_AdcADC_RES_HSCMPPOL_MASK        (CSD_ADC_RES_HSCMP_POL_Msk)
#define CapSense_1_AdcADC_RES_VALUE_MASK           (CSD_ADC_RES_VIN_CNT_Msk)
#define CapSense_1_AdcUNDERFLOW_LIMIT              (8000u)

#endif  /* CapSense_1_ADC_EN */

#endif  /* CY_SENSE_CapSense_1_ADC_H */


/* [] END OF FILE */
