/***************************************************************************//**
* \file CapSense_1_Structure.c
* \version 3.0
*
* \brief
*   This file defines the data structure global variables and provides implementation
*   for the high-level and low-level APIs of the Data Structure module.
*
* \see CapSense_1 v3.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2017), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#include <string.h>
#include "syslib/cy_syslib.h"
#include "cyfitter_gpio.h"
#include "CapSense_1_Structure.h"
#include "CapSense_1_Configuration.h"

#if (0u != CapSense_1_ADC_EN)
    #include "CapSense_1_Adc.h"
#endif /* (0u != CapSense_1_ADC_EN) */

/*******************************************************************************
* Defines the RAM Data Structure variables and their init data in flash
*******************************************************************************/
/**
* \cond SECTION_GLOBAL_VARIABLES
* \addtogroup group_global_variables
* \{
*/

/**
* The variable that contains the CapSense_1 configuration, settings and
* scanning results. CapSense_1_dsRam represents RAM Data Structure.
*/
CapSense_1_RAM_STRUCT CapSense_1_dsRam;
/** \}
* \endcond */

/**
* \cond SECTION_API_CONSTANTS
* \addtogroup group_api_constants
* \{
*/


/**
 *  The array of the pointers to the ADC input channels specific register.
 */
const CapSense_1_FLASH_IO_STRUCT CapSense_1_adcIoList[CapSense_1_ADC_TOTAL_CHANNELS] =
{
    {
        CapSense_1_AdcInput_0_PORT,
        (uint8)CapSense_1_AdcInput_0_NUM,
    },
    {
        CapSense_1_AdcInput_1_PORT,
        (uint8)CapSense_1_AdcInput_1_NUM,
    },
};


/** \}
* \endcond */


/*******************************************************************************
* Function Name: CapSense_1_DsInitialize
****************************************************************************//**
*
* \brief
*   This function initializes the Data Structure storage.
*
* \details
*   Configures the initial Adc datastructure members.
*
*******************************************************************************/
void CapSense_1_AdcDsInitialize(void)
{
    /* Reset RAM data structure content */
    (void)memset(&CapSense_1_dsRam, 0, sizeof(CapSense_1_dsRam));

    CapSense_1_dsRam.adcResolution = CapSense_1_ADC_RESOLUTION;
    CapSense_1_dsRam.adcIdac = (uint8)(CapSense_1_ADC_IDAC_DEFAULT);
    CapSense_1_dsRam.adcActiveCh = CapSense_1_AdcNO_CHANNEL;
}

/* [] END OF FILE */
